@@ -1,8 +1,9 @@
 #!/usr/bin/env python3
 import sys
 import argparse
-import threading
 import avutil
+import avutil.source
+import avutil.encoder
 
 from multiprocessing.dummy import Pool
 
@@ -11,7 +12,8 @@ sys.setrecursionlimit(10000)
 src_folder = "./"
 dst_folder = "./"
 http_proxy = ""
-source = avutil.Library
+source = avutil.source.Library
+encoder = avutil.encoder.NFOEncoder
 thread = 8
 with_poster = False
 
@@ -21,6 +23,7 @@ def VideoProcess(video):
     global dst_folder
     global http_proxy
     global source
+    global encoder
     global thread
     global with_poster
 
@@ -31,7 +34,7 @@ def VideoProcess(video):
         # Pull AV info
         video.pull_info(source=source, http_proxy=http_proxy)
         if video.is_updated:
-            print("[%8s] %s" % (video.designatio, video.title))
+            print("[%8s] %s" % (video.info.designatio, video.info.title))
 
         # Download cover
         video.download_cover(dst_dir=dst_folder,
@@ -41,7 +44,7 @@ def VideoProcess(video):
         video.rename(dst_dir=dst_folder)
 
         # Save video info as .nfo
-        video.save_info(dst_dir=dst_folder)
+        video.save_info(dst_dir=dst_folder, encoder=encoder)
     except Exception as e:
         print("WARN:", e)
         pass
@@ -62,6 +65,8 @@ def get_arguments(args=sys.argv[1:]):
                         help="data source of video info, 'library' or 'bus'")
     parser.add_argument("-t", "--thread", dest='thread', type=int,
                         help="threads num, use multi-threads to download info & images")
+    parser.add_argument("-e", "--encoder", dest='encoder',
+                        help="encoder of meta-data, 'nfo'(default) or 'vsmeta'")
     parser.add_argument("--with-poster", dest='with_poster', action='store_true',
                         help="save poster")
     return parser.parse_args(args)
@@ -73,6 +78,7 @@ def main():
     global dst_folder
     global http_proxy
     global source
+    global encoder
     global thread
     global with_poster
 
@@ -91,7 +97,11 @@ def main():
 
     # Data source
     if args.source == "bus":
-        source = avutil.Bus
+        source = avutil.source.Bus
+
+    # Encoder
+    if args.encoder == "vsmeta":
+        encoder = avutil.encoder.VSMETAEncoder
 
     # Gen poster
     if args.with_poster == True:
@@ -110,8 +120,11 @@ def main():
         videos = avutil.Search_folder(src_folder)
 
     # Threads work
-    jobs = [v for v in videos.items()]
-    pool = Pool(thread)
-    pool.map(VideoProcess, jobs)
-    pool.close()
-    pool.join()
\ No newline at end of file
+    if thread == 1:
+        for v in videos.items():
+            VideoProcess(v)
+    else:
+        pool = Pool(thread)
+        pool.map(VideoProcess, videos.items())
+        pool.close()
+        pool.join()
